==> dokuwiki-2011.05.25a.tgz: dokuwiki/lib/plugins/revert/lang/pt-br/lang.php <==
<?php
/**
 * Portuguese language file
 *
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 * @author Jair Henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luisdantas@gmail.com>
 * @author Sergio Motta sergio@cisne.com.br
 * @author Isaias Masiero Filho <masiero@masiero.org>
 */
$lang['menu']                  = 'Gerenciador de reversões';
$lang['filter']                = 'Procura por páginas com spam';
$lang['revert']                = 'Reverte as páginas selecionadas';
$lang['reverted']              = '%s revertida para a revisão %s';
$lang['removed']               = '% removida';
$lang['revstart']              = 'O processo de reversão foi iniciado. Isso pode levar muito tempo. Se o tempo de execução do script expirar antes dele encerrar, você deverá tentar novamente usando blocos menores.';
$lang['revstop']               = 'O processo de reversão terminou com sucesso.';
$lang['note1']                 = 'Nota: esta busca diferencia maiúsculas/minúsculas';
$lang['note2']                 = 'Nota: a página será revertida para a última versão que não contém o termo de spam <i>%s</i>.';

==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/revert/lang/pt-br/lang.php <==
<?php
/**
 * Portuguese language file
 *
 * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Lucien Raven <lucienraven@yahoo.com.br>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Flávio Veras <flaviove@gmail.com>
 * @author Jeferson Propheta <jeferson.propheta@gmail.com>
 * @author jair.henrique@gmail.com
 * @author Luis Dantas <luis@dantas.com>
 * @author Frederico Guimarães <frederico@teia.bio.br>
 * @author Jair Henrique <jair.henrique@gmail.com>
 * @author Luis Dantas <luisdantas@gmail.com>
 * @author Sergio Motta sergio@cisne.com.br
 * @author Isaias Masiero Filho <masiero@masiero.org>
 * @author Balaco Baco <balacobaco@imap.cc>
 * @author Victor Westmann <victor.westmann@gmail.com>
 */
$lang['menu']                  = 'Gerenciador de reversões';
$lang['filter']                = 'Procura por páginas com spam';
$lang['revert']                = 'Reverte as páginas selecionadas';
$lang['reverted']              = '%s revertida para a revisão %s';
$lang['removed']               = '%s removida';
$lang['revstart']              = 'O processo de reversão foi iniciado. Isso pode levar muito tempo. Se o tempo de execução do script expirar antes dele encerrar, você deverá tentar novamente usando blocos menores.';
$lang['revstop']               = 'O processo de reversão terminou com sucesso.';
$lang['note1']                 = 'Nota: esta busca diferencia maiúsculas/minúsculas';
$lang['note2']                 = 'Nota: a página será revertida para a última versão que não contém o termo de spam <i>%s</i>.';
